package
Version:
v0.0.0-...-56a5d22
Opens a new window with list of versions in this module.
Published: Jun 5, 2017
License: MIT
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func GetAssertion(t T) assertion
type T interface {
Fail()
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.